@@ -15,6 +15,12 @@
    along with this program; if not, write to the Free Software
    Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA. */
 
+#ifdef STRINGS_H
+#  include <strings.h>
+#else
+#  include <string.h>
+#endif 
+
 #ifndef _GETOPT_H
 #define _GETOPT_H 1
 
